@@ -25,7 +25,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.3.0"
+#define LIBGNUTLS_VERSION "0.3.1"
 
 #include <sys/types.h>
 #include <time.h>
@@ -50,7 +50,6 @@ typedef enum AlertDescription { GNUTLS_A_CLOSE_NOTIFY, GNUTLS_A_UNEXPECTED_MESSA
 			GNUTLS_A_NO_RENEGOTIATION=100
 } AlertDescription;
 
-typedef enum GNUTLS_NAME_IND { GNUTLS_DNSNAME=1 } GNUTLS_NAME_IND; 
 typedef enum CertificateStatus { GNUTLS_CERT_TRUSTED=1, GNUTLS_CERT_NOT_TRUSTED, GNUTLS_CERT_EXPIRED, GNUTLS_CERT_INVALID, GNUTLS_CERT_NONE } CertificateStatus;
 typedef enum CertificateRequest { GNUTLS_CERT_IGNORE, GNUTLS_CERT_REQUEST=1, GNUTLS_CERT_REQUIRE } CertificateRequest;
 typedef enum CloseRequest { GNUTLS_SHUT_RDWR=0, GNUTLS_SHUT_WR=1 } CloseRequest;
@@ -72,20 +71,10 @@ typedef struct {
 	int size;
 } gnutls_datum;
 
-typedef enum PKAlgorithm { GNUTLS_PK_RSA = 1, GNUTLS_PK_DSA,	/* sign only */
-	GNUTLS_PK_DH
-} PKAlgorithm;
-
-/* You cannot use these structures directly
- */
-typedef struct gnutls_cert gnutls_cert;
-typedef struct gnutls_private_key gnutls_private_key;
-
-
 /* internal functions */
 
 int gnutls_init(GNUTLS_STATE * state, ConnectionEnd con_end);
-int gnutls_deinit(GNUTLS_STATE state);
+void gnutls_deinit(GNUTLS_STATE state);
 int gnutls_bye( GNUTLS_STATE state, CloseRequest how);
 
 int gnutls_handshake( GNUTLS_STATE state);
@@ -111,7 +100,9 @@ const char *gnutls_kx_get_name( KXAlgorithm algorithm);
 
 
 /* error functions */
-int gnutls_is_fatal_error( int error);
+int gnutls_error_is_fatal( int error);
+#define gnutls_is_fatal_error(x) gnutls_error_is_fatal(x)
+
 void gnutls_perror( int error);
 const char* gnutls_strerror( int error);
 
@@ -155,7 +146,7 @@ int  gnutls_db_check_entry( GNUTLS_STATE state, gnutls_datum session_entry);
 void gnutls_handshake_set_max_data_buffer_size( GNUTLS_STATE state, int max);
 
 /* returns libgnutls version */
-const char* gnutls_check_version();
+const char* gnutls_check_version(void);
 
 /* Functions for setting/clearing credentials */
 int gnutls_clear_creds( GNUTLS_STATE state);
@@ -170,40 +161,47 @@ int gnutls_cred_set( GNUTLS_STATE, CredType type, void* cred);
 /* Credential structures for SRP - used in gnutls_set_cred(); */
 
 struct DSTRUCT;
-typedef struct DSTRUCT* X509PKI_CREDENTIALS;
-typedef X509PKI_CREDENTIALS X509PKI_CLIENT_CREDENTIALS;
-typedef X509PKI_CREDENTIALS X509PKI_SERVER_CREDENTIALS;
+typedef struct DSTRUCT* GNUTLS_X509PKI_CREDENTIALS;
+typedef GNUTLS_X509PKI_CREDENTIALS GNUTLS_X509PKI_CLIENT_CREDENTIALS;
+typedef GNUTLS_X509PKI_CREDENTIALS GNUTLS_X509PKI_SERVER_CREDENTIALS;
+#define X509PKI_CLIENT_CREDENTIALS GNUTLS_X509PKI_CLIENT_CREDENTIALS
+#define X509PKI_SERVER_CREDENTIALS GNUTLS_X509PKI_SERVER_CREDENTIALS
 
-typedef struct DSTRUCT* SRP_SERVER_CREDENTIALS;
-typedef struct DSTRUCT* SRP_CLIENT_CREDENTIALS;
+typedef struct DSTRUCT* GNUTLS_SRP_SERVER_CREDENTIALS;
+typedef struct DSTRUCT* GNUTLS_SRP_CLIENT_CREDENTIALS;
+#define SRP_SERVER_CREDENTIALS GNUTLS_SRP_SERVER_CREDENTIALS
+#define SRP_CLIENT_CREDENTIALS GNUTLS_GNUTLS_SRP_CLIENT_CREDENTIALS
 
-typedef struct DSTRUCT* ANON_SERVER_CREDENTIALS;
-typedef struct DSTRUCT* ANON_CLIENT_CREDENTIALS;
+typedef struct DSTRUCT* GNUTLS_ANON_SERVER_CREDENTIALS;
+typedef struct DSTRUCT* GNUTLS_ANON_CLIENT_CREDENTIALS;
+#define ANON_SERVER_CREDENTIALS GNUTLS_ANON_SERVER_CREDENTIALS
+#define ANON_CLIENT_CREDENTIALS GNUTLS_ANON_CLIENT_CREDENTIALS
 
-void gnutls_srp_free_client_sc( SRP_CLIENT_CREDENTIALS sc);
-int gnutls_srp_allocate_client_sc( SRP_CLIENT_CREDENTIALS *sc);
-int gnutls_srp_set_client_cred( SRP_CLIENT_CREDENTIALS res, char *username, char* password);
 
-void gnutls_srp_free_server_sc( SRP_SERVER_CREDENTIALS sc);
-int gnutls_srp_allocate_server_sc( SRP_SERVER_CREDENTIALS *sc);
-int gnutls_srp_set_server_cred_file( SRP_SERVER_CREDENTIALS res, char *password_file, char* password_conf_file);
+void gnutls_srp_free_client_sc( GNUTLS_SRP_CLIENT_CREDENTIALS sc);
+int gnutls_srp_allocate_client_sc( GNUTLS_SRP_CLIENT_CREDENTIALS *sc);
+int gnutls_srp_set_client_cred( GNUTLS_SRP_CLIENT_CREDENTIALS res, char *username, char* password);
 
-void gnutls_anon_free_server_sc( ANON_SERVER_CREDENTIALS sc);
-int gnutls_anon_allocate_server_sc( ANON_SERVER_CREDENTIALS *sc);
-int gnutls_anon_set_server_cred( ANON_SERVER_CREDENTIALS res, int dh_bits);
+void gnutls_srp_free_server_sc( GNUTLS_SRP_SERVER_CREDENTIALS sc);
+int gnutls_srp_allocate_server_sc( GNUTLS_SRP_SERVER_CREDENTIALS *sc);
+int gnutls_srp_set_server_cred_file( GNUTLS_SRP_SERVER_CREDENTIALS res, char *password_file, char* password_conf_file);
 
-void gnutls_anon_free_client_sc( ANON_SERVER_CREDENTIALS sc);
-int gnutls_anon_allocate_client_sc( ANON_SERVER_CREDENTIALS *sc);
-int gnutls_anon_set_client_cred( ANON_SERVER_CREDENTIALS res, int dh_bits);
+void gnutls_anon_free_server_sc( GNUTLS_ANON_SERVER_CREDENTIALS sc);
+int gnutls_anon_allocate_server_sc( GNUTLS_ANON_SERVER_CREDENTIALS *sc);
+int gnutls_anon_set_server_cred( GNUTLS_ANON_SERVER_CREDENTIALS res, int dh_bits);
+
+void gnutls_anon_free_client_sc( GNUTLS_ANON_SERVER_CREDENTIALS sc);
+int gnutls_anon_allocate_client_sc( GNUTLS_ANON_SERVER_CREDENTIALS *sc);
+int gnutls_anon_set_client_cred( GNUTLS_ANON_SERVER_CREDENTIALS res, int dh_bits);
 
 
 /* CERTFILE is an x509 certificate in PEM form.
  * KEYFILE is a pkcs-1 private key in PEM form (for RSA keys).
  */
-void gnutls_x509pki_free_sc( X509PKI_CREDENTIALS sc);
-int gnutls_x509pki_allocate_sc( X509PKI_CREDENTIALS *sc, int ncerts);
-int gnutls_x509pki_set_key_file( X509PKI_CREDENTIALS res, char *CERTFILE, char* KEYFILE);
-int gnutls_x509pki_set_trust_file( X509PKI_CREDENTIALS res, char* CAFILE, char* CRLFILE);
+void gnutls_x509pki_free_sc( GNUTLS_X509PKI_CREDENTIALS sc);
+int gnutls_x509pki_allocate_sc( GNUTLS_X509PKI_CREDENTIALS *sc, int ncerts);
+int gnutls_x509pki_set_key_file( GNUTLS_X509PKI_CREDENTIALS res, char *CERTFILE, char* KEYFILE);
+int gnutls_x509pki_set_trust_file( GNUTLS_X509PKI_CREDENTIALS res, char* CAFILE, char* CRLFILE);
 
 #define gnutls_x509pki_free_server_sc gnutls_x509pki_free_sc
 #define gnutls_x509pki_allocate_server_sc gnutls_x509pki_allocate_sc
@@ -222,8 +220,8 @@ int gnutls_x509pki_set_trust_file( X509PKI_CREDENTIALS res, char* CAFILE, char*
  * This will not be the case in the final version. These files 
  * are located in the src/ directory of gnutls distribution.
  */
-int gnutls_global_init();
-void gnutls_global_deinit();
+int gnutls_global_init(void);
+void gnutls_global_deinit(void);
 
 int gnutls_dh_replace_params( gnutls_datum prime, gnutls_datum generator, int bits);
 int gnutls_dh_generate_params( gnutls_datum* prime, gnutls_datum* generator, int bits);
@@ -237,8 +235,11 @@ void gnutls_transport_set_lowat( GNUTLS_STATE state, int num);
 
 typedef void (*LOG_FUNC)( const char*);
 
-void gnutls_transport_set_push_function( GNUTLS_STATE, GNUTLS_PUSH_FUNC push_func);
-void gnutls_transport_set_pull_function( GNUTLS_STATE, GNUTLS_PULL_FUNC pull_func);
+void gnutls_transport_set_push_func( GNUTLS_STATE, GNUTLS_PUSH_FUNC push_func);
+void gnutls_transport_set_pull_func( GNUTLS_STATE, GNUTLS_PULL_FUNC pull_func);
+
+#define gnutls_transport_set_push_function gnutls_transport_set_push_func
+#define gnutls_transport_set_pull_function gnutls_transport_set_pull_func
 
 size_t gnutls_record_get_max_size( GNUTLS_STATE state);
 size_t gnutls_record_set_max_size( GNUTLS_STATE state, size_t size);
@@ -249,36 +250,36 @@ size_t gnutls_record_set_max_size( GNUTLS_STATE state, size_t size);
 
 /* Extra definitions */
 
-#define X509_CN_SIZE 256
-#define X509_C_SIZE 3
-#define X509_O_SIZE 256
-#define X509_OU_SIZE 256
-#define X509_L_SIZE 256
-#define X509_S_SIZE 256
-#define X509_EMAIL_SIZE 256
+#define GNUTLS_X509_CN_SIZE 256
+#define GNUTLS_X509_C_SIZE 3
+#define GNUTLS_X509_O_SIZE 256
+#define GNUTLS_X509_OU_SIZE 256
+#define GNUTLS_X509_L_SIZE 256
+#define GNUTLS_X509_S_SIZE 256
+#define GNUTLS_X509_EMAIL_SIZE 256
 
 typedef struct {
-	char common_name[X509_CN_SIZE];
-	char country[X509_C_SIZE];
-	char organization[X509_O_SIZE];
-	char organizational_unit_name[X509_OU_SIZE];
-	char locality_name[X509_L_SIZE];
-	char state_or_province_name[X509_S_SIZE];
-	char email[X509_EMAIL_SIZE];
+	char common_name[GNUTLS_X509_CN_SIZE];
+	char country[GNUTLS_X509_C_SIZE];
+	char organization[GNUTLS_X509_O_SIZE];
+	char organizational_unit_name[GNUTLS_X509_OU_SIZE];
+	char locality_name[GNUTLS_X509_L_SIZE];
+	char state_or_province_name[GNUTLS_X509_S_SIZE];
+	char email[GNUTLS_X509_EMAIL_SIZE];
 } gnutls_DN;
 
 /* For key Usage, test as:
  * if (st.keyUsage & X509KEY_DIGITAL_SIGNATURE) ...
  */
-#define X509KEY_DIGITAL_SIGNATURE 	256
-#define X509KEY_NON_REPUDIATION		128
-#define X509KEY_KEY_ENCIPHERMENT	64
-#define X509KEY_DATA_ENCIPHERMENT	32
-#define X509KEY_KEY_AGREEMENT		16
-#define X509KEY_KEY_CERT_SIGN		8
-#define X509KEY_CRL_SIGN		4
-#define X509KEY_ENCIPHER_ONLY		2
-#define X509KEY_DECIPHER_ONLY		1
+#define GNUTLS_X509KEY_DIGITAL_SIGNATURE 	256
+#define GNUTLS_X509KEY_NON_REPUDIATION		128
+#define GNUTLS_X509KEY_KEY_ENCIPHERMENT	64
+#define GNUTLS_X509KEY_DATA_ENCIPHERMENT	32
+#define GNUTLS_X509KEY_KEY_AGREEMENT		16
+#define GNUTLS_X509KEY_KEY_CERT_SIGN		8
+#define GNUTLS_X509KEY_CRL_SIGN		4
+#define GNUTLS_X509KEY_ENCIPHER_ONLY		2
+#define GNUTLS_X509KEY_DECIPHER_ONLY		1
 
 
 # ifdef LIBGNUTLS_VERSION /* These are defined only in gnutls.h */
@@ -302,9 +303,9 @@ int gnutls_anon_client_get_dh_bits( GNUTLS_STATE state);
 
 /* X509PKI */
 
-void gnutls_x509pki_set_client_cert_callback( X509PKI_CREDENTIALS, x509pki_client_cert_callback_func *);
+void gnutls_x509pki_set_client_cert_callback( GNUTLS_X509PKI_CREDENTIALS, x509pki_client_cert_callback_func *);
 
-void gnutls_x509pki_set_server_cert_callback( X509PKI_CREDENTIALS, x509pki_server_cert_callback_func *);
+void gnutls_x509pki_set_server_cert_callback( GNUTLS_X509PKI_CREDENTIALS, x509pki_server_cert_callback_func *);
 void gnutls_x509pki_server_set_cert_request( GNUTLS_STATE, CertificateRequest);
 
 void gnutls_x509pki_set_dh_bits( GNUTLS_STATE state, int bits);
