@@ -21,6 +21,10 @@
 #include "gnutls_auth.h"
 
 /* functions for version */
+
+GNUTLS_Version _gnutls_version_lowest( GNUTLS_STATE state);
+GNUTLS_Version _gnutls_version_max( GNUTLS_STATE state);
+int _gnutls_version_priority(GNUTLS_STATE state, GNUTLS_Version version);
 int _gnutls_version_is_supported(GNUTLS_STATE state, const GNUTLS_Version version);
 int _gnutls_version_get_major( GNUTLS_Version ver);
 int _gnutls_version_get_minor( GNUTLS_Version ver);
@@ -28,7 +32,7 @@ GNUTLS_Version _gnutls_version_get( int major, int minor);
 
 /* functions for macs */
 int   _gnutls_mac_get_digest_size(MACAlgorithm algorithm);
-char* gnutls_mac_get_name(MACAlgorithm algorithm);
+const char* gnutls_mac_get_name(MACAlgorithm algorithm);
 int   _gnutls_mac_is_ok(MACAlgorithm algorithm);
 int   _gnutls_mac_priority(GNUTLS_STATE state, MACAlgorithm algorithm);
 int   _gnutls_mac_count();
@@ -40,7 +44,7 @@ int   _gnutls_supported_ciphersuites_sorted(GNUTLS_STATE state, GNUTLS_CipherSui
 int   _gnutls_supported_compression_methods(GNUTLS_STATE state, uint8 **comp);
 
 int   _gnutls_cipher_suite_count();
-char* _gnutls_cipher_suite_get_name(GNUTLS_CipherSuite algorithm);
+const char* _gnutls_cipher_suite_get_name(GNUTLS_CipherSuite algorithm);
 BulkCipherAlgorithm _gnutls_cipher_suite_get_cipher_algo(const GNUTLS_CipherSuite algorithm);
 KXAlgorithm _gnutls_cipher_suite_get_kx_algo(const GNUTLS_CipherSuite algorithm);
 MACAlgorithm _gnutls_cipher_suite_get_mac_algo(const GNUTLS_CipherSuite algorithm);
@@ -54,13 +58,13 @@ int _gnutls_cipher_count();
 int _gnutls_cipher_is_ok(BulkCipherAlgorithm algorithm);
 int _gnutls_cipher_get_key_size(BulkCipherAlgorithm algorithm);
 int _gnutls_cipher_get_iv_size(BulkCipherAlgorithm algorithm);
-char *gnutls_cipher_get_name(BulkCipherAlgorithm algorithm);
+const char *gnutls_cipher_get_name(BulkCipherAlgorithm algorithm);
 
 /* functions for key exchange */
 int _gnutls_kx_priority(GNUTLS_STATE state, KXAlgorithm algorithm);
 
 MOD_AUTH_STRUCT * _gnutls_kx_auth_struct(KXAlgorithm algorithm);
-char *gnutls_kx_get_name(KXAlgorithm algorithm);
+const char *gnutls_kx_get_name(KXAlgorithm algorithm);
 int _gnutls_kx_is_ok(KXAlgorithm algorithm);
 int _gnutls_kx_count();
 
@@ -70,7 +74,7 @@ int _gnutls_compression_is_ok(CompressionMethod algorithm);
 int _gnutls_compression_count();
 int _gnutls_compression_get_num(CompressionMethod algorithm);
 CompressionMethod _gnutls_compression_get_id(int num);
-char *gnutls_compression_get_name(CompressionMethod algorithm);
+const char *gnutls_compression_get_name(CompressionMethod algorithm);
 
 /* Type to KX mappings */
 KXAlgorithm _gnutls_map_kx_get_kx(CredType type);
