@@ -391,7 +391,7 @@ ssize_t _gnutls_read_buffered( GNUTLS_STATE state, opaque **iptr, size_t sizeOfP
 		/* return immediately if we got an interrupt or eagain
 		 * error.
 		 */
-		if (ret < 0 && gnutls_is_fatal_error(ret)==0) {
+		if (ret < 0 && gnutls_error_is_fatal(ret)==0) {
 			return ret;
 		}
 	}
@@ -415,7 +415,7 @@ ssize_t _gnutls_read_buffered( GNUTLS_STATE state, opaque **iptr, size_t sizeOfP
 	if (ret == (recvdata - recvlowat) && recvlowat > 0) {
 		ret2 = _gnutls_read( state, &buf[buf_pos], recvlowat, MSG_PEEK);
 
-		if (ret2 < 0 && gnutls_is_fatal_error(ret2)==0) {
+		if (ret2 < 0 && gnutls_error_is_fatal(ret2)==0) {
 			return ret2;
 		}
 
@@ -704,7 +704,7 @@ ssize_t _gnutls_handshake_send_int( GNUTLS_STATE state, ContentType type, Handsh
 #ifdef WRITE_DEBUG
 		size_t sum=0, x, j;
 		
-		_gnutls_log( "HWRITE: will write %d bytes to %d.\n", n, fd);
+		_gnutls_log( "HWRITE: will write %d bytes to %d.\n", n, gnutls_transport_get_ptr(state));
 		for (x=0;x<((n)/16)+1;x++) {
 			if (sum>n)
 				break;
