@@ -37,5 +37,5 @@
 
 const char* gnutls_strerror(int error);
 void gnutls_perror(int error);
-int gnutls_is_fatal_error( int error);
+int gnutls_error_is_fatal( int error);
 void _gnutls_log( const char *fmt, ...);
