@@ -36,11 +36,11 @@ LOG_FUNC _gnutls_log_func;
 static node_asn *PKIX1_ASN;
 static node_asn *PKCS1_ASN;
 
-node_asn* _gnutls_get_pkix() {
+node_asn* _gnutls_get_pkix(void) {
 	return PKIX1_ASN;
 }
 
-node_asn* _gnutls_get_pkcs() {
+node_asn* _gnutls_get_pkcs(void) {
 	return PKCS1_ASN;
 }
 
@@ -78,7 +78,7 @@ static void dlog( const char* str) {
   * Returns zero on success.
   *
   **/
-int gnutls_global_init()
+int gnutls_global_init( void)
 {
 	int result;
 
@@ -118,9 +118,10 @@ int gnutls_global_init()
   * gnutls_global_deinit - This function deinitializes the global state 
   *
   * This function deinitializes the global state.
+  *
   **/
 
-void gnutls_global_deinit() {
+void gnutls_global_deinit( void) {
 
 	asn1_delete_structure( PKCS1_ASN);
 	asn1_delete_structure( PKIX1_ASN);
@@ -135,7 +136,7 @@ void gnutls_global_deinit() {
  */
 
 /**
-  * gnutls_transport_set_pull_function - This function sets a read like function
+  * gnutls_transport_set_pull_func - This function sets a read like function
   * @pull_func: it's a function like read
   * @state: gnutls state
   *
@@ -147,12 +148,12 @@ void gnutls_global_deinit() {
   * PULL_FUNC is of the form, 
   * ssize_t (*PULL_FUNC)(GNUTLS_SOCKET_PTR, const void*, size_t);
   **/
-void gnutls_transport_set_pull_function( GNUTLS_STATE state, PULL_FUNC pull_func) {
+void gnutls_transport_set_pull_func( GNUTLS_STATE state, PULL_FUNC pull_func) {
 	state->gnutls_internals._gnutls_pull_func = pull_func;
 }
 
 /**
-  * gnutls_transport_set_push_function - This function sets the function to send data
+  * gnutls_transport_set_push_func - This function sets the function to send data
   * @push_func: it's a function like write
   * @state: gnutls state
   *
@@ -166,6 +167,6 @@ void gnutls_transport_set_pull_function( GNUTLS_STATE state, PULL_FUNC pull_func
   * PUSH_FUNC is of the form, 
   * ssize_t (*PUSH_FUNC)(GNUTLS_SOCKET_PTR, const void*, size_t);
   **/
-void gnutls_transport_set_push_function( GNUTLS_STATE state, PUSH_FUNC push_func) {
+void gnutls_transport_set_push_func( GNUTLS_STATE state, PUSH_FUNC push_func) {
 	state->gnutls_internals._gnutls_push_func = push_func;
 }
