@@ -1,4 +1,4 @@
-AlertDescription gnutls_get_last_alert( GNUTLS_STATE state);
+AlertDescription gnutls_alert_get_last( GNUTLS_STATE state);
 KXAlgorithm gnutls_kx_get_algo( GNUTLS_STATE state);
 ssize_t gnutls_send_int( GNUTLS_STATE state, ContentType type, HandshakeType htype, const void* data, size_t sizeofdata);
 ssize_t gnutls_recv_int( GNUTLS_STATE state, ContentType type, HandshakeType, char* data, size_t sizeofdata);
