@@ -172,9 +172,9 @@ int main(int argc, char** argv)
 	int maxfd;
 	struct timeval tv;
 	int user_term = 0;
-	SRP_CLIENT_CREDENTIALS cred;
-	ANON_CLIENT_CREDENTIALS anon_cred;
-	X509PKI_CLIENT_CREDENTIALS xcred;
+	GNUTLS_SRP_CLIENT_CREDENTIALS cred;
+	GNUTLS_ANON_CLIENT_CREDENTIALS anon_cred;
+	GNUTLS_X509PKI_CLIENT_CREDENTIALS xcred;
 	struct hostent* server_host;
 	
 	signal( SIGPIPE, SIG_IGN);
@@ -363,7 +363,7 @@ int main(int argc, char** argv)
 			} while( ret==GNUTLS_E_INTERRUPTED || ret==GNUTLS_E_AGAIN);
 			/* remove new line */
 
-			if (gnutls_is_fatal_error(ret) == 1 || ret==0) {
+			if (gnutls_error_is_fatal(ret) == 1 || ret==0) {
 				if (ret == 0) {
 					printf("- Peer has closed the GNUTLS connection\n");
 					break;
