@@ -66,9 +66,9 @@ static char http_buffer[16*1024];
 #define RENEGOTIATE
 
 /* These are global */
-SRP_SERVER_CREDENTIALS srp_cred;
-ANON_SERVER_CREDENTIALS dh_cred;
-X509PKI_SERVER_CREDENTIALS x509_cred;
+GNUTLS_SRP_SERVER_CREDENTIALS srp_cred;
+GNUTLS_ANON_SERVER_CREDENTIALS dh_cred;
+GNUTLS_X509PKI_SERVER_CREDENTIALS x509_cred;
 
 
 GNUTLS_STATE initialize_state()
@@ -424,7 +424,7 @@ int main(int argc, char **argv)
 			bzero(buffer, MAX_BUF + 1);
 			ret = read_request( state, buffer, MAX_BUF, (http==0)?1:2);
 
-			if (gnutls_is_fatal_error(ret) == 1 || ret == 0) {
+			if (gnutls_error_is_fatal(ret) == 1 || ret == 0) {
 				fflush(stdout);
 				if (ret == 0) {
 					printf
